@@ -517,7 +517,8 @@ export const updateSecondaryHeader = (
   links,
   actions,
   tooltip,
-  mainButton
+  label,
+  labelColor
 ) => {
   return {
     type: Actions.SECONDARY_HEADER_UPDATE,
@@ -527,7 +528,8 @@ export const updateSecondaryHeader = (
     links,
     actions,
     tooltip,
-    mainButton
+    label,
+    labelColor
   }
 }
 
@@ -637,6 +639,7 @@ export const mutateResourceSuccessFinished = resourceType => ({
 export const clearSuccessFinished = dispatch => {
   [
     RESOURCE_TYPES.QUERY_APPLICATIONS,
+    RESOURCE_TYPES.QUERY_APPLICATIONSET,
     RESOURCE_TYPES.QUERY_CHANNELS,
     RESOURCE_TYPES.QUERY_SUBSCRIPTIONS,
     RESOURCE_TYPES.QUERY_PLACEMENTRULES
