@@ -16,7 +16,10 @@ import {
   getSharedSubscriptionWarning
 } from './utils'
 import React from 'react'
-import { AcmIcon, AcmIconVariant } from '@stolostron/ui-components'
+import {
+  AcmIcon,
+  AcmIconVariant
+} from '@open-cluster-management/ui-components'
 
 const prePostTasks = [
   ////////////////////////////////////////////////////////////////////////////////////
