@@ -10,7 +10,7 @@ import { withRouter } from 'react-router-dom'
 import {
   AcmAutoRefreshSelect,
   AcmRefreshTime
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 
 import { getSelectedId } from './QuerySwitcher'
 import {
@@ -139,7 +139,8 @@ const mapStateToProps = (state, ownProps) => {
   const routePaths = location ? _.get(location, 'pathname', '').split('/') : []
   const isEditTab =
     routePaths.length === 6 || //edit app
-    (routePaths.length === 4 && routePaths[3] === 'create') //new app
+    (routePaths.length === 4 &&
+      ['create' || 'argoappset'].indexOf(routePaths[3]) !== -1) //new app or argoappset
   if (isEditTab) {
     //this is the editor tab, the refresh action is not showing here
     return { isEditTab: true }
