@@ -4,13 +4,7 @@
 
 import React from 'react'
 import PropTypes from 'prop-types'
-import {
-  Divider,
-  Label,
-  Popover,
-  Stack,
-  StackItem
-} from '@patternfly/react-core'
+import { Label, Popover } from '@patternfly/react-core'
 import resources from '../../../lib/shared/resources'
 
 resources(() => {
@@ -21,24 +15,21 @@ const LabelWithPopover = ({
   children,
   labelContent,
   labelIcon,
-  labelColor
+  labelColor,
+  popoverHeader,
+  popoverPosition
 }) => (
   <div className="label-with-popover">
     <Popover
-      bodyContent={
-        <Stack>
-          <StackItem className="close-button-spacer" />
-          <StackItem>
-            <Divider />
-          </StackItem>
-          <StackItem>{children}</StackItem>
-        </Stack>
-      }
+      headerContent={popoverHeader}
+      bodyContent={children}
       className="label-with-popover"
       enableFlip
-      position="bottom"
+      hasAutoWidth
+      minWidth="18.75rem"
+      maxWidth="30rem"
+      position={popoverPosition || 'bottom'}
       flipBehavior={['bottom', 'top', 'right', 'left']}
-      distance={10}
       zIndex={999}
     >
       <Label
@@ -47,7 +38,7 @@ const LabelWithPopover = ({
           event.nativeEvent.preventDefault()
           event.stopPropagation()
         }}
-        color={labelColor ? labelColor : 'grey'}
+        color={labelColor || 'grey'}
         href="#"
         icon={labelIcon}
       >
@@ -60,8 +51,10 @@ const LabelWithPopover = ({
 LabelWithPopover.propTypes = {
   children: PropTypes.object,
   labelColor: PropTypes.string,
-  labelContent: PropTypes.object,
-  labelIcon: PropTypes.object
+  labelContent: PropTypes.node,
+  labelIcon: PropTypes.object,
+  popoverHeader: PropTypes.node,
+  popoverPosition: PropTypes.string
 }
 
 export default LabelWithPopover
