@@ -33,7 +33,7 @@ import {
   AcmAlert,
   AcmButton,
   AcmDescriptionList
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 import resources from '../../../../lib/shared/resources'
 import msgs from '../../../../nls/platform.properties'
 import config from '../../../../lib/shared/config'
@@ -132,6 +132,10 @@ class OverviewCards extends React.Component {
     } = this.props
     const { argoLinkLoading, showSubCards, hasSyncPermissions } = this.state
     const cluster = _.get(topology, 'activeFilters.application.cluster')
+    const apiVersion = _.split(
+      _.get(topology, 'activeFilters.application.apiVersion', ''),
+      '/'
+    )
 
     if (topology.status === REQUEST_STATUS.CLUSTER_OFFLINE) {
       const infoMessage = _.get(
@@ -154,7 +158,10 @@ class OverviewCards extends React.Component {
 
     const targetLink = getSearchLinkForOneApplication({
       name: encodeURIComponent(selectedAppName),
-      namespace: encodeURIComponent(selectedAppNS)
+      namespace: encodeURIComponent(selectedAppNS),
+      cluster: encodeURIComponent(cluster),
+      apiGroup: encodeURIComponent(apiVersion[0]),
+      apiVersion: encodeURIComponent(apiVersion[1])
     })
 
     const appOverviewCardsData = getAppOverviewCardsData(
@@ -513,7 +520,9 @@ class OverviewCards extends React.Component {
                           this.getArgoSearchLink(
                             selectedAppName,
                             selectedAppNS,
-                            cluster
+                            cluster,
+                            apiVersion[0],
+                            apiVersion[1]
                           )
                         }
                         variant={ButtonVariant.link}
@@ -625,7 +634,8 @@ class OverviewCards extends React.Component {
           selfLink: '',
           _uid: '',
           kind: '',
-          apiVersion: ''
+          apiVersion: '',
+          itemGroup: []
         }
       }
     })
@@ -659,11 +669,19 @@ class OverviewCards extends React.Component {
     )
   };
 
-  getArgoSearchLink = (selectedAppName, selectedAppNS, cluster) => {
+  getArgoSearchLink = (
+    selectedAppName,
+    selectedAppNS,
+    cluster,
+    apiGroup,
+    apiVersion
+  ) => {
     return getSearchLinkForOneApplication({
       name: encodeURIComponent(selectedAppName),
       namespace: encodeURIComponent(selectedAppNS),
-      cluster: encodeURIComponent(cluster)
+      cluster: encodeURIComponent(cluster),
+      apiGroup: encodeURIComponent(apiGroup),
+      apiVersion: encodeURIComponent(apiVersion)
     })
   };
 
