@@ -14,7 +14,12 @@
 import React from 'react'
 import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
-import { AcmHeader, AcmPage, AcmRoute } from '@stolostron/ui-components'
+import {
+  AcmHeader,
+  AcmPage,
+  AcmRoute
+} from '@open-cluster-management/ui-components'
+import queryString from 'query-string'
 import SecondaryHeader from '../components/SecondaryHeader'
 import { Route, Switch, Redirect, withRouter } from 'react-router-dom'
 import { withLocale } from '../providers/LocaleProvider'
@@ -44,8 +49,8 @@ export const AdvancedConfigurationPage = loadable(() =>
   import(/* webpackChunkName: "advancedConfigurationPage" */ '../components/AdvancedConfigurationPage')
 )
 
-export const CreateApplicationButton = loadable(() =>
-  import(/* webpackChunkName: "createApplicationButton" */ '../components/common/CreateApplicationButton')
+export const ArgoCreationPage = loadable(() =>
+  import(/* webpackChunkName: "ArgoCreationPage" */ '../components/ArgoCreationPage/ArgoCreationPage')
 )
 
 resources(() => {
@@ -100,14 +105,13 @@ class App extends React.Component {
       }
     ]
 
-    const createApplicationButton = <CreateApplicationButton key="create" />
-
     const getSingleApplicationBasePath = params => {
       return `${BASE_PAGE_PATH}/${params.namespace}/${params.name}`
     }
 
     const getSingleApplicationTabs = params => {
-      const isArgoApp = _.get(location, 'search').indexOf('argoproj.io') !== -1
+      const searchParams = queryString.parse(_.get(location, 'search'))
+      const { apiVersion, applicationset, cluster } = searchParams
       const SINGLE_APP_BASE_PAGE_PATH = getSingleApplicationBasePath(params)
       const overviewTab = [
         {
@@ -116,15 +120,16 @@ class App extends React.Component {
           url: SINGLE_APP_BASE_PAGE_PATH
         }
       ]
-      if (isArgoApp) {
-        return overviewTab
-      } else {
-        return _.concat(overviewTab, {
-          id: 'editor',
-          label: 'description.title.editor',
-          url: `${SINGLE_APP_BASE_PAGE_PATH}/edit`
-        })
+      if (apiVersion === 'argoproj.io/v1alpha1') {
+        if (!applicationset || cluster) {
+          return overviewTab
+        }
       }
+      return _.concat(overviewTab, {
+        id: 'editor',
+        label: 'description.title.editor',
+        url: `${SINGLE_APP_BASE_PAGE_PATH}/edit`
+      })
     }
 
     const applicationsTitle = 'routes.applications'
@@ -141,8 +146,7 @@ class App extends React.Component {
                 serverProps={this.getServerProps()}
                 secondaryHeaderProps={{
                   title: applicationsTitle,
-                  tabs: allApplicationsTabs,
-                  mainButton: createApplicationButton
+                  tabs: allApplicationsTabs
                 }}
               />
             )}
@@ -156,8 +160,7 @@ class App extends React.Component {
                 serverProps={serverProps}
                 secondaryHeaderProps={{
                   title: applicationsTitle,
-                  tabs: allApplicationsTabs,
-                  mainButton: createApplicationButton
+                  tabs: allApplicationsTabs
                 }}
                 locale={locale}
               />
@@ -174,6 +177,21 @@ class App extends React.Component {
               />
             )}
           />
+          <Route
+            exact
+            path={`${BASE_PAGE_PATH}/argoappset`}
+            render={params => (
+              <ArgoCreationPage
+                params={params}
+                serverProps={this.getServerProps()}
+                secondaryHeaderProps={{
+                  title: 'argo.create.title',
+                  label: 'creation.app.section.techPreview',
+                  labelColor: 'creation.app.section.techPreview.color'
+                }}
+              />
+            )}
+          />
           <Route
             exact
             path={`${BASE_PAGE_PATH}/:namespace/:name`}
@@ -191,16 +209,28 @@ class App extends React.Component {
           <Route
             exact
             path={`${BASE_PAGE_PATH}/:namespace/:name/edit`}
-            render={params => (
-              <ApplicationCreationPage
-                params={params}
-                serverProps={this.getServerProps()}
-                secondaryHeaderProps={{
-                  title: 'application.create.title',
-                  tabs: getSingleApplicationTabs(params.match.params)
-                }}
-              />
-            )}
+            render={routeProps => {
+              const params = queryString.parse(routeProps.location.search)
+              return params.apiVersion === 'argoproj.io/v1alpha1' ? (
+                <ArgoCreationPage
+                  params={params}
+                  serverProps={this.getServerProps()}
+                  secondaryHeaderProps={{
+                    title: 'argo.create.title',
+                    tabs: getSingleApplicationTabs(routeProps.match.params)
+                  }}
+                />
+              ) : (
+                <ApplicationCreationPage
+                  params={routeProps}
+                  serverProps={this.getServerProps()}
+                  secondaryHeaderProps={{
+                    title: 'application.create.title',
+                    tabs: getSingleApplicationTabs(routeProps.match.params)
+                  }}
+                />
+              )
+            }}
           />
           <Redirect to={`${config.contextPath}/welcome`} />
         </Switch>
