@@ -1,7 +1,5 @@
-/** *****************************************************************************
- * Licensed Materials - Property of Red Hat, Inc.
- * Copyright (c) 2020 Red Hat, Inc.
- ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 /// <reference types="cypress" />
 
@@ -15,7 +13,7 @@ Cypress.Commands.add("installAnsibleOperator", () => {
         timeout: 20 * 1000
       })
       .then(({ stdout }) => {
-        if (stdout.includes("automation-controller-operator")) {
+        if (stdout.includes("tower-resource-operator")) {
           cy.log(`AnsibleOperator already exists.`);
         } else {
           cy.log(`Installing AnsibleOperator ...`);
@@ -26,7 +24,7 @@ Cypress.Commands.add("installAnsibleOperator", () => {
             }
           );
           cy.exec(
-            `oc delete deployment automation-controller-operator-controller-manager -n app-ui-ansibleoperator`,
+            `oc delete deployment tower-resource-operator -n app-ui-ansibleoperator`,
             { failOnNonZeroExit: false }
           );
           cy
