@@ -1,9 +1,7 @@
-/*******************************************************************************
- * Licensed Materials - Property of Red Hat, Inc.
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
-const config = JSON.parse(Cypress.env("TEST_CONFIG"));
+const config = Cypress.env("TEST_CONFIG_EXCLUDE_ARGO");
 import { addNewSubscription } from "../../views/application";
 import {
   getManagedClusterName,
