@@ -6,6 +6,7 @@ import {
   pageLoader,
   resourceTable,
   modal,
+  navigateApplication,
   notification,
   noResource,
   indexedCSS,
@@ -33,9 +34,13 @@ export const createApplication = (
   type,
   namespace = "default"
 ) => {
-  cy.visit("/multicloud/applications");
-  // wait for create button to be enabled
-  cy.get("[data-test-create-application=true]", { timeout: 50 * 1000 }).click();
+  navigateApplication();
+  cy
+    .get('li[id="application.type.acm"]', {
+      timeout: 50 * 1000
+    })
+    .children(".pf-c-dropdown__menu-item")
+    .click();
   const { name, config } = data;
   namespace == "default" ? (namespace = `${name}-ns`) : namespace;
   cy.log(`Test create application ${name}`);
@@ -87,13 +92,14 @@ export const gitTasks = (clusterName, value, gitCss, key = 0) => {
     .get(`#git`)
     .last()
     .scrollIntoView()
-    .click()
-    .trigger("mouseover");
-
+    .trigger("mouseover")
+    .click();
   checkExistingUrls(gitUser, username, gitKey, token, gitUrl, url);
 
   if (insecureSkipVerifyOption) {
-    cy.get(insecureSkipVerify).click({ force: true });
+    cy
+      .get(insecureSkipVerify, { timeout: 20 * 1000, withinSubject: null })
+      .click({ force: true });
   }
   // type in branch and path
   cy.get(".bx—inline.loading", { timeout: 30 * 1000 }).should("not.exist");
@@ -101,7 +107,7 @@ export const gitTasks = (clusterName, value, gitCss, key = 0) => {
   // the git api is unreliable and we don't want to fail all git app tests
   //if the branch doesn't show up
   cy
-    .get(gitBranch, { timeout: 50 * 1000 })
+    .get(gitBranch, { timeout: 50 * 1000, withinSubject: null })
     .type(branch, { timeout: 50 * 1000 })
     .blur();
 
@@ -109,19 +115,19 @@ export const gitTasks = (clusterName, value, gitCss, key = 0) => {
   cy.get(".bx—inline.loading", { timeout: 30 * 1000 }).should("not.exist");
   //type in folder name here instead of trying to select one, same reason as above, for branch
   cy
-    .get(gitPath, { timeout: 20 * 1000 })
+    .get(gitPath, { timeout: 20 * 1000, withinSubject: null })
     .type(path, { timeout: 30 * 1000 })
     .blur();
 
   commitHash &&
     cy
-      .get(gitCommitHash, { timeout: 20 * 1000 })
+      .get(gitCommitHash, { timeout: 20 * 1000, withinSubject: null })
       .type(commitHash, { timeout: 30 * 1000 })
       .blur();
 
   tag &&
     cy
-      .get(gitTag, { timeout: 20 * 1000 })
+      .get(gitTag, { timeout: 20 * 1000, withinSubject: null })
       .type(tag, { timeout: 30 * 1000 })
       .blur();
 
@@ -138,7 +144,9 @@ export const gitTasks = (clusterName, value, gitCss, key = 0) => {
       .type(repositoryReconcileRate, { force: true });
   }
   if (disableAutoReconcileOption) {
-    cy.get(disableAutoReconcile).click({ force: true });
+    cy
+      .get(disableAutoReconcile, { withinSubject: null })
+      .click({ force: true });
   }
   selectPrePostTasks(value, key);
   selectClusterDeployment(deployment, clusterName, key);
@@ -206,8 +214,7 @@ export const helmTasks = (clusterName, value, css, key = 0) => {
   cy
     .get("#helm")
     .last()
-    .click()
-    .trigger("mouseover");
+    .click();
 
   checkExistingUrls(
     helmUsername,
@@ -219,13 +226,18 @@ export const helmTasks = (clusterName, value, css, key = 0) => {
   );
 
   if (insecureSkipVerifyOption) {
-    cy.get(insecureSkipVerify).click({ force: true });
+    cy
+      .get(insecureSkipVerify, { timeout: 20 * 1000, withinSubject: null })
+      .click({ force: true });
   }
   cy
-    .get(helmChartName, { timeout: 20 * 1000 })
+    .get(helmChartName, { timeout: 20 * 1000, withinSubject: null })
     .type(chartName)
     .blur();
-  packageAlias && cy.get(helmPackageAlias, { timeout: 20 * 1000 }).clear();
+  packageAlias &&
+    cy
+      .get(helmPackageAlias, { timeout: 20 * 1000, withinSubject: null })
+      .clear();
   packageAlias &&
     cy
       .get(helmPackageAlias, { timeout: 20 * 1000 })
@@ -234,15 +246,19 @@ export const helmTasks = (clusterName, value, css, key = 0) => {
 
   packageVersion &&
     cy
-      .get(helmPackageVersion, { timeout: 20 * 1000 })
+      .get(helmPackageVersion, { timeout: 20 * 1000, withinSubject: null })
       .type(packageVersion)
       .blur();
 
   if (repositoryReconcileRate) {
-    cy.get(reconcileRate).type(repositoryReconcileRate, { force: true });
+    cy
+      .get(reconcileRate, { withinSubject: null })
+      .type(repositoryReconcileRate, { force: true });
   }
   if (disableAutoReconcileOption) {
-    cy.get(disableAutoReconcile).click({ force: true });
+    cy
+      .get(disableAutoReconcile, { withinSubject: null })
+      .click({ force: true });
   }
 
   selectClusterDeployment(deployment, clusterName, key);
@@ -318,8 +334,7 @@ export const objTasks = (clusterName, value, css, key = 0) => {
   cy
     .get("#object-storage")
     .last()
-    .click()
-    .trigger("mouseover");
+    .click();
 
   checkExistingUrls(objAccess, accessKey, objSecret, secretKey, objUrl, url);
   selectClusterDeployment(deployment, clusterName, key);
@@ -564,12 +579,12 @@ export const validateAppTableMenu = (name, resourceTable) => {
   }
   const resourceKey = getResourceKey(name, getNamespace(name), "local-cluster");
   resourceTable.openRowMenu(name, resourceKey);
-  resourceTable.menuClick("search");
+  resourceTable.menuClick("search application");
   cy
     .url()
     .should(
       "include",
-      `multicloud/search?filters={%22textsearch%22:%22name%3A${name}%20namespace%3A${name}-ns%20kind%3Aapplication%20apigroup%3Aapp.k8s.io%22}`
+      `search?filters={%22textsearch%22:%22name%3A${name}%20namespace%3A${name}-ns%20cluster%3Alocal-cluster%20kind%3Aapplication%20apigroup%3Aapp.k8s.io%20apiversion%3Av1beta1%22}`
     );
 
   //get back to app page
@@ -645,7 +660,7 @@ export const validateResourceTable = (
   }
   resourceTable.getRow(name, resourceKey).within(() =>
     resourceTable
-      .getCell("Namespace", type === "argo" ? 2 : null)
+      .getCell("Namespace", type === "argo" ? 3 : null)
       .invoke("text")
       .should("include", type === "argo" ? deployedNamespace : namespace)
   );
@@ -686,7 +701,7 @@ export const validateResourceTable = (
     resourceTable
       .getCell("Resource")
       .find(".pf-c-label")
-      .click()
+      .click({ force: true })
   );
 
   data.config.forEach(item => {
