@@ -146,11 +146,12 @@ var Helpers = {
     };
   },
   getDefaultBrushArea: function (targetProps, cachedDomain, evt) {
-    var defaultBrushArea = targetProps.defaultBrushArea,
-        domain = targetProps.domain,
+    var domain = targetProps.domain,
         fullDomain = targetProps.fullDomain,
         scale = targetProps.scale,
-        horizontal = targetProps.horizontal;
+        horizontal = targetProps.horizontal,
+        allowResize = targetProps.allowResize;
+    var defaultBrushArea = !allowResize && !targetProps.defaultBrushArea ? "move" : targetProps.defaultBrushArea;
 
     if (defaultBrushArea === "none") {
       return this.getMinimumDomain();
@@ -275,7 +276,8 @@ var Helpers = {
         allowResize = targetProps.allowResize,
         allowDrag = targetProps.allowDrag,
         allowDraw = targetProps.allowDraw;
-    var brushDimension = this.getDimension(targetProps); // Don't trigger events for static brushes
+    var brushDimension = this.getDimension(targetProps);
+    var defaultBrushArea = !allowResize && !targetProps.defaultBrushArea ? "move" : targetProps.defaultBrushArea; // Don't trigger events for static brushes
 
     if (!allowResize && !allowDrag) {
       return {};
@@ -347,7 +349,7 @@ var Helpers = {
         target: "parent",
         mutation: function () {
           return _objectSpread({
-            isSelecting: allowResize,
+            isSelecting: allowResize || defaultBrushArea === "move",
             domainBox: domainBox,
             fullDomainBox: fullDomainBox,
             parentSVG: parentSVG,
@@ -474,8 +476,8 @@ var Helpers = {
         onBrushCleared = targetProps.onBrushCleared,
         currentDomain = targetProps.currentDomain,
         allowResize = targetProps.allowResize,
-        allowDrag = targetProps.allowDrag,
-        defaultBrushArea = targetProps.defaultBrushArea;
+        allowDrag = targetProps.allowDrag;
+    var defaultBrushArea = !allowResize && !targetProps.defaultBrushArea ? "move" : targetProps.defaultBrushArea;
     var defaultBrushHasArea = defaultBrushArea !== undefined && defaultBrushArea !== "none";
     var mutatedProps = {
       isPanning: false,
