@@ -713,7 +713,9 @@ module.exports = {
 		"8.2.1",
 		"8.2.2",
 		"8.2.3",
-		"8.5.3"
+		"8.5.3",
+		"8.5.4",
+		"8.5.5"
 	],
 	"80.0.3987.165": [
 		"8.2.4",
@@ -845,7 +847,14 @@ module.exports = {
 		"9.3.0",
 		"9.3.1",
 		"9.3.2",
-		"9.3.3"
+		"9.3.3",
+		"9.3.4",
+		"9.3.5",
+		"9.4.0",
+		"9.4.1",
+		"9.4.2",
+		"9.4.3",
+		"9.4.4"
 	],
 	"84.0.4129.0": [
 		"10.0.0-beta.1",
@@ -986,7 +995,19 @@ module.exports = {
 	"85.0.4183.121": [
 		"10.1.3",
 		"10.1.4",
-		"10.1.5"
+		"10.1.5",
+		"10.1.6",
+		"10.1.7",
+		"10.2.0",
+		"10.3.0",
+		"10.3.1",
+		"10.3.2",
+		"10.4.0",
+		"10.4.1",
+		"10.4.2",
+		"10.4.3",
+		"10.4.4",
+		"10.4.5"
 	],
 	"86.0.4234.0": [
 		"11.0.0-beta.1",
@@ -1023,6 +1044,13 @@ module.exports = {
 		"11.0.0-beta.18",
 		"11.0.0-beta.19"
 	],
+	"87.0.4280.40": [
+		"11.0.0-beta.20"
+	],
+	"87.0.4280.47": [
+		"11.0.0-beta.22",
+		"11.0.0-beta.23"
+	],
 	"85.0.4156.0": [
 		"11.0.0-nightly.20200529"
 	],
@@ -1066,6 +1094,86 @@ module.exports = {
 		"11.0.0-nightly.20200811",
 		"11.0.0-nightly.20200812"
 	],
+	"87.0.4280.60": [
+		"11.0.0",
+		"11.0.1"
+	],
+	"87.0.4280.67": [
+		"11.0.2",
+		"11.0.3",
+		"11.0.4"
+	],
+	"87.0.4280.88": [
+		"11.0.5",
+		"11.1.0",
+		"11.1.1"
+	],
+	"87.0.4280.141": [
+		"11.2.0",
+		"11.2.1",
+		"11.2.2",
+		"11.2.3",
+		"11.3.0",
+		"11.4.0",
+		"11.4.1",
+		"11.4.2",
+		"11.4.3",
+		"11.4.4",
+		"11.4.5"
+	],
+	"89.0.4328.0": [
+		"12.0.0-beta.1",
+		"12.0.0-beta.3",
+		"12.0.0-beta.4",
+		"12.0.0-beta.5",
+		"12.0.0-beta.6",
+		"12.0.0-beta.7",
+		"12.0.0-beta.8",
+		"12.0.0-beta.9",
+		"12.0.0-beta.10",
+		"12.0.0-beta.11",
+		"12.0.0-beta.12",
+		"12.0.0-beta.14",
+		"13.0.0-nightly.20201119",
+		"13.0.0-nightly.20201123",
+		"13.0.0-nightly.20201124",
+		"13.0.0-nightly.20201126",
+		"13.0.0-nightly.20201127",
+		"13.0.0-nightly.20201130",
+		"13.0.0-nightly.20201201",
+		"13.0.0-nightly.20201202",
+		"13.0.0-nightly.20201203",
+		"13.0.0-nightly.20201204",
+		"13.0.0-nightly.20201207",
+		"13.0.0-nightly.20201208",
+		"13.0.0-nightly.20201209",
+		"13.0.0-nightly.20201210",
+		"13.0.0-nightly.20201211",
+		"13.0.0-nightly.20201214"
+	],
+	"89.0.4348.1": [
+		"12.0.0-beta.16",
+		"12.0.0-beta.18",
+		"12.0.0-beta.19",
+		"12.0.0-beta.20"
+	],
+	"89.0.4388.2": [
+		"12.0.0-beta.21",
+		"12.0.0-beta.22",
+		"12.0.0-beta.23",
+		"12.0.0-beta.24",
+		"12.0.0-beta.25",
+		"12.0.0-beta.26"
+	],
+	"89.0.4389.23": [
+		"12.0.0-beta.27",
+		"12.0.0-beta.28",
+		"12.0.0-beta.29"
+	],
+	"89.0.4389.58": [
+		"12.0.0-beta.30",
+		"12.0.0-beta.31"
+	],
 	"87.0.4268.0": [
 		"12.0.0-nightly.20201013",
 		"12.0.0-nightly.20201014",
@@ -1077,6 +1185,129 @@ module.exports = {
 	],
 	"88.0.4306.0": [
 		"12.0.0-nightly.20201030",
-		"12.0.0-nightly.20201102"
+		"12.0.0-nightly.20201102",
+		"12.0.0-nightly.20201103",
+		"12.0.0-nightly.20201104",
+		"12.0.0-nightly.20201105",
+		"12.0.0-nightly.20201106",
+		"12.0.0-nightly.20201111",
+		"12.0.0-nightly.20201112"
+	],
+	"88.0.4324.0": [
+		"12.0.0-nightly.20201116"
+	],
+	"89.0.4389.69": [
+		"12.0.0"
+	],
+	"89.0.4389.82": [
+		"12.0.1"
+	],
+	"89.0.4389.90": [
+		"12.0.2"
+	],
+	"89.0.4389.114": [
+		"12.0.3",
+		"12.0.4"
+	],
+	"89.0.4389.128": [
+		"12.0.5",
+		"12.0.6"
+	],
+	"90.0.4402.0": [
+		"13.0.0-beta.2",
+		"13.0.0-beta.3",
+		"13.0.0-nightly.20210210",
+		"13.0.0-nightly.20210211",
+		"13.0.0-nightly.20210212",
+		"13.0.0-nightly.20210216",
+		"13.0.0-nightly.20210217",
+		"13.0.0-nightly.20210218",
+		"13.0.0-nightly.20210219",
+		"13.0.0-nightly.20210222",
+		"13.0.0-nightly.20210225",
+		"13.0.0-nightly.20210226",
+		"13.0.0-nightly.20210301",
+		"13.0.0-nightly.20210302",
+		"13.0.0-nightly.20210303",
+		"14.0.0-nightly.20210304"
+	],
+	"90.0.4415.0": [
+		"13.0.0-beta.4",
+		"13.0.0-beta.5",
+		"13.0.0-beta.6",
+		"13.0.0-beta.7",
+		"13.0.0-beta.8",
+		"13.0.0-beta.9",
+		"13.0.0-beta.11",
+		"13.0.0-beta.12",
+		"13.0.0-beta.13",
+		"14.0.0-nightly.20210305",
+		"14.0.0-nightly.20210308",
+		"14.0.0-nightly.20210309",
+		"14.0.0-nightly.20210311",
+		"14.0.0-nightly.20210315",
+		"14.0.0-nightly.20210316",
+		"14.0.0-nightly.20210317",
+		"14.0.0-nightly.20210318",
+		"14.0.0-nightly.20210319",
+		"14.0.0-nightly.20210323",
+		"14.0.0-nightly.20210324",
+		"14.0.0-nightly.20210325",
+		"14.0.0-nightly.20210326",
+		"14.0.0-nightly.20210329",
+		"14.0.0-nightly.20210330"
+	],
+	"91.0.4448.0": [
+		"13.0.0-beta.14",
+		"13.0.0-beta.16",
+		"13.0.0-beta.17",
+		"13.0.0-beta.18",
+		"13.0.0-beta.20",
+		"14.0.0-nightly.20210331",
+		"14.0.0-nightly.20210401",
+		"14.0.0-nightly.20210402",
+		"14.0.0-nightly.20210406",
+		"14.0.0-nightly.20210407",
+		"14.0.0-nightly.20210408",
+		"14.0.0-nightly.20210409",
+		"14.0.0-nightly.20210413"
+	],
+	"89.0.4349.0": [
+		"13.0.0-nightly.20201215",
+		"13.0.0-nightly.20201216",
+		"13.0.0-nightly.20201221",
+		"13.0.0-nightly.20201222"
+	],
+	"89.0.4359.0": [
+		"13.0.0-nightly.20201223",
+		"13.0.0-nightly.20210104",
+		"13.0.0-nightly.20210108",
+		"13.0.0-nightly.20210111"
+	],
+	"89.0.4386.0": [
+		"13.0.0-nightly.20210113",
+		"13.0.0-nightly.20210114",
+		"13.0.0-nightly.20210118",
+		"13.0.0-nightly.20210122",
+		"13.0.0-nightly.20210125"
+	],
+	"89.0.4389.0": [
+		"13.0.0-nightly.20210127",
+		"13.0.0-nightly.20210128",
+		"13.0.0-nightly.20210129",
+		"13.0.0-nightly.20210201",
+		"13.0.0-nightly.20210202",
+		"13.0.0-nightly.20210203",
+		"13.0.0-nightly.20210205",
+		"13.0.0-nightly.20210208",
+		"13.0.0-nightly.20210209"
+	],
+	"92.0.4475.0": [
+		"14.0.0-nightly.20210426",
+		"14.0.0-nightly.20210427"
+	],
+	"92.0.4488.0": [
+		"14.0.0-nightly.20210430",
+		"14.0.0-nightly.20210503"
 	]
 };
\ No newline at end of file
